#
# spec file for package fbi
#
# Copyright (c) 2023 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fbi
Version:        2.14
Release:        4.1
Summary:        Image Viewer for the Linux Framebuffer Console
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            https://www.kraxel.org/blog/linux/fbida/
Source0:        https://www.kraxel.org/releases/fbida/fbida-%{version}.tar.gz
Source1:        https://www.kraxel.org/releases/fbida/fbida-%{version}.tar.gz.asc
Source2:        fbi.keyring
Patch0:         fbi.patch
BuildRequires:  curl-devel
BuildRequires:  freetype2-devel
BuildRequires:  giflib-devel >= 5.1.0
BuildRequires:  libjpeg-devel
BuildRequires:  libpcd-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(poppler-glib)
Requires:       ghostscript-library

%description
This is a image viewer for Linux framebuffer devices. It has PhotoCD,
jpeg, ppm, gif, tiff, xwd, bmp, and png support built-in.  Unknown
formats are piped through convert (ImageMagick), which hopefully can
handle it.

%package -n exiftran
Summary:        Digital Camera JPEG image transformation utility
License:        LGPL-2.1-or-later
Group:          Productivity/Graphics/Other

%description -n exiftran
exiftran is a command-line utility to transform digital image JPEG
images. It can do lossless rotations like jpegtran, but unlike
jpegtran, it cares about the EXIF data.  It can rotate images
automatically by checking the EXIF orientation tag, updating the EXIF
information if needed (image dimension, orientation), and also rotating
the EXIF thumbnail. It can process multiple images at once.

%package -n fbpdf
Summary:        PDF viewer for Linux framebuffer devices
License:        LGPL-2.1-or-later
Group:          Productivity/Graphics/Viewers

%description -n fbpdf
This is a PDF viewer for Linux framebuffer devices. It uses the poppler
library for rendering.

%prep
%autosetup -p1 -n fbida-%{version}

%build
%make_build prefix=%{_prefix} exiftran fbi

%install
%make_install prefix=%{_prefix}

%files
%license COPYING
%{_bindir}/fbgs
%{_bindir}/fbi
%{_mandir}/man1/fbgs.*
%{_mandir}/man1/fbi.*

%files -n exiftran
%license COPYING
%{_bindir}/exiftran
%{_mandir}/man1/exiftran.*

%files -n fbpdf
%license COPYING
%{_bindir}/fbpdf

%changelog
* Mon Apr 10 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Disable usage of optional cairo-gl surface in fbpdf, cairo-gl
  has been deprecated/removed by upstream.
- Clean up spec file.
* Sun Jul  5 2020 olaf@aepfle.de
- Fix build with fbi.patch
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase for summaries.
* Sat Aug 17 2019 antoine.belvire@opensuse.org
- Update to version 2.14: No changelog provided.
- Add tarball signature verification:
  * Add Gerd Hoffmann's public key as source (fbi.keyring).
  * Add tarball signature as source.
* Wed May 11 2016 stefan.bruens@rwth-aachen.de
- Update to version 2.12:
  * add poppler based fbpdf
- Update to version 2.11:
  * Untangled the console switching code from the fbdev code.
  * Added support for drm, which also is the new default.
  * Missing console switching support is not a fatal error any more.
  - > fbi can be used from a remote login
* Sun Jan 17 2016 p.drouand@gmail.com
- Update to version 2.10
  * No changelog available
- Remove 0001-fix-misssing-space.patch; fixed on upstream release
- Perform a spec-cleaner
* Thu May 10 2012 toganm@opensuse.org
- cleanup
  * fixed file-contains-date-and-time warning
  * removed not used ida.png and ida-desktop.patch
* Wed May  9 2012 toganm@opensuse.org
- reworked package
  * remove dependency to openmotif-devel and therefore remove
  subpackage ida due to licensing (bnc#761246)
  * fix fbi man page display error
* Wed May  2 2012 toganm@opensuse.org
- update to 2.09
  * fix /usr/share/X11/app-defaults/Ida installation
* Sun Aug  7 2011 lazy.kent@opensuse.org
- update to 2.08
- removed libpng-1.4 and jpeg-8.0.2 patches (fixed upstream)
- fix build dependencies (requires libpcd-devel)
- fbi package requires ghostscript-library to run fbgs script
- added desktop_database_post/un macros for ida
- updated site URL
- corrected License tags
- use full URL for source
- man pages marked as doc
- minor spec formatting
* Thu Feb 17 2011 pgajdos@suse.cz
- apply fbi-jpeg-8.0.2.patch conditionally (only for 11.3)
  [bnc#648885]
* Mon Dec 20 2010 puzel@novell.com
- disable fbi-jpeg-8.0.2.patch - fix build
* Tue Nov 23 2010 pgajdos@suse.cz
- use jpeg 8.0.2 headers and transupp.c [bnc#648855]
* Fri May  7 2010 puzel@novell.com
- add fbi-libpng-1.4.patch: fix build with new libpng
* Wed Jan 28 2009 mvyskocil@suse.cz
- fixed BR: libpcd2-devel
* Wed Jun 25 2008 puzel@suse.cz
- updated to 2.07
  * bugfix release
  * removed fbida-2.06.diff (fixed in upstream)
* Sat Apr 26 2008 coolo@suse.de
- remove unused header
* Tue Jul 17 2007 pcerny@suse.cz
- fixed some rpmlint complaints
* Wed May  9 2007 pcerny@suse.cz
- updated to 2.06
* Sat Mar  3 2007 aj@suse.de
- Fix buildrequires.
* Mon Nov  6 2006 cthiel@suse.de
- fix build (images in /usr/share/pixmaps/ don't need to be executable)
* Tue Aug  8 2006 cthiel@suse.de
- fix build with X.org 7.1
* Tue Jul 25 2006 kraxel@suse.de
- update to version 2.05
  * bugfix release, #194659, DSA 1124-1
* Thu Jun 15 2006 kraxel@suse.de
- update to version 2.04
  * bugfix release, closes #168728
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 schwab@suse.de
- Don't strip binaries.
* Tue Jan 25 2005 kraxel@suse.de
- update to version 2.03
* Mon Jan 10 2005 adrian@suse.de
- fix last fix
* Tue Dec 14 2004 hvogel@suse.de
- fix desktop file
* Mon Nov  8 2004 kraxel@suse.de
- update to version 2.02
* Fri Jul 30 2004 meissner@suse.de
- Ported to use new libexif.
* Tue Jun  8 2004 kraxel@suse.de
- update to version 2.00
* Thu Mar 25 2004 kraxel@suse.de
- remove workaround for #34903 (fixed now).
* Tue Mar  9 2004 kraxel@suse.de
- workaround #34903.
* Fri Mar  5 2004 kraxel@suse.de
- add libexif to neededforbuild.
* Thu Feb 26 2004 kraxel@suse.de
- updated to version 1.31.
* Thu Jan 29 2004 kraxel@suse.de
- updated to version 1.30.
* Wed Jan  7 2004 kraxel@suse.de
- updated to version 1.29, added exiftran subpackage.
* Fri Oct 17 2003 kraxel@suse.de
- updated to version 1.28
* Fri Feb  7 2003 kraxel@suse.de
- updated to version 1.26
* Thu Jun 20 2002 kraxel@suse.de
- updated to version 1.25
* Tue Apr 30 2002 kraxel@suse.de
- updated to version 1.24
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Jan 28 2002 kraxel@suse.de
- initial release.
